import request from '@/helpers/request';
import wxChat from 'weixin-js-sdk';

/**
 * 微信分享页面配置标题和内容
 * @params shareTitle 分享标题
 * @params shareDescribe 分享描述
 * @params imgUrl 分享图片
 */
export default function useWeChatShare(
  shareTitle: string,
  shareDescribe: string,
  imgUrl: string
) {
  /**
   * 获取微信分享签名并设置分享内容
   */
  const getAppSignature = () => {
    // 获取微信分享签名
    request
      .get('/edu-app/open/wechat/getSignature', {
        params: {
          url: window.location.href
        }
      })
      .then(res => {
        if (res.code === 200) {
          setWeChatShare(res.data);
        } else {
          console.log('获取微信分享签名失败');
        }
      });
  };
  const setWeChatShare = (data: any) => {
    console.log(wxChat, 'wxChat');
    wxChat.config({
      debug: false, // 开启调试模式,调用的所有api的返回值会在客户端alert出来，若要查看传入的参数，可以在pc端打开，参数信息会通过log打出，仅在pc端时才会打印。
      appId: data.appId, // 必填，公众号的唯一标识
      timestamp: data.timestamp, // 必填，生成签名的时间戳
      nonceStr: data.nonceStr, // 必填，生成签名的随机串
      signature: data.signature, // 必填，签名
      jsApiList: [
        'updateAppMessageShareData',
        'updateTimelineShareData',
        'onMenuShareAppMessage',
        'onMenuShareTimeline'
      ] // 必填，需要使用的JS接口列表
    });

    wxChat.ready(function () {
      console.log("wx.ready called");

      // 自定义“分享给朋友”及“分享到QQ”按钮的分享内容
      wxChat.updateAppMessageShareData({
        title: shareTitle, // 分享标题
        desc: shareDescribe, // 分享描述
        link: window.location.href, // 分享链接，该链接域名或路径必须与当前页面对应的公众号JS安全域名一致
        imgUrl, // 分享图标
        success: function () {
          // 设置成功
          console.log('updateAppMessageShareData 设置成功');
        }
      });

      // 获取“分享给朋友”按钮点击状态及自定义分享内容接口
      wxChat.onMenuShareAppMessage({
        title: shareTitle, // 分享标题
        desc: shareDescribe, // 分享描述
        link: window.location.href, // 分享链接，该链接域名或路径必须与当前页面对应的公众号JS安全域名一致
        imgUrl, // 分享图标
        type: 'link',
        success: function () {
          // 设置成功
          console.log('onMenuShareAppMessage 设置成功');
        },
        cancel: function () {
          // 用户取消分享后执行的回调函数
        }
      });
      // 获取“分享到朋友圈”按钮点击状态及自定义分享内容接口
      wxChat.onMenuShareTimeline({
        title: shareTitle, // 分享标题
        // desc: shareDescribe, // 分享描述
        link: window.location.href, // 分享链接，该链接域名或路径必须与当前页面对应的公众号JS安全域名一致
        imgUrl, // 分享图标
        success: function () {
          // 设置成功
          console.log('onMenuShareTimeline 设置成功');
        },
        cancel: function () {
          // 用户取消分享后执行的回调函数
        }
      });

      // 自定义“分享到朋友圈”及“分享到QQ空间”按钮的分享内容
      wxChat.updateTimelineShareData({
        title: shareTitle, // 分享标题
        // desc: shareDescribe, // 分享描述
        link: window.location.href, // 分享链接，该链接域名或路径必须与当前页面对应的公众号JS安全域名一致
        imgUrl, // 分享图标
        success: function () {
          // 设置成功
          console.log('updateTimelineShareData 设置成功');
        }
      });
    });
    wxChat.error(function (res) {
      // console.log(res);
      // console.log(that.shareTitle, that.shareDescribe,'分享错误');
    });
  };
  return {
    getAppSignature
  };
}
