import { defineComponent, toRefs } from 'vue';
import styles from './chapter-course.module.less';
import iconMenuChapter from '../image/icon-course-c.svg';
import iconCourseTimer from '../image/icon-course-timer.svg';
import iconCurrentImg from '../image/icon-current-img.png';
import { NoticeBar } from 'vant';

export default defineComponent({
  name: 'chapter',
  props: {
    detail: {
      type: Object,
      default: () => []
    },
    itemActive: {
      type: String,
      default: ''
    },
    popShow: {
      type: Boolean,
      default: false
    }
  },
  emits: ['handleSelect'],
  setup(props, { emit }) {
    const { detail, itemActive } = toRefs(props);

    // watch(
    //   () => props.popShow,
    //   () => {
    //     if (props.popShow) {
    //       // pointData.active = props.active;
    //     }
    //   }
    // );
    return () => (
      <div class={styles.container}>
        <div class={styles.pointHead}>
          <img src={iconMenuChapter} />
          上课记录
        </div>
        <div class={styles.content}>
          <div class={styles.list}>
            {detail.value.map((year: any) => (
              <div class={styles.item}>
                <h2>
                  {year.year}
                  <span>年</span>
                </h2>
                {year.list.map((month: any) => (
                  <div>
                    <h3>{month.month}月</h3>

                    {month.list.map((item: any) => (
                      <div
                        class={[
                          styles.item_inner,
                          itemActive.value === item.courseId
                            ? styles.active
                            : ''
                        ]}
                        key={item.courseId}
                        onClick={() => {
                          emit('handleSelect', {
                            itemActive: item.courseId
                          });
                        }}>
                        {itemActive.value === item.courseId ? (
                          <img src={iconCurrentImg} class={styles.currentImg} />
                        ) : (
                          ''
                        )}

                        <div class={styles.title}>
                          <NoticeBar text={item.courseName} scrollable={itemActive.value === item.courseId} />
                        </div>
                        <div class={styles.timers}>
                          <img
                            src={iconCourseTimer}
                            class={styles.courseTimer}
                          />
                          <span>上课时间：{item.classDate}</span>
                        </div>
                      </div>
                    ))}
                  </div>
                ))}
              </div>
            ))}
          </div>
        </div>
      </div>
    );
  }
});
